@@ -1,30 +1,29 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from __future__ import unicode_literals
 
 from trytond.pool import PoolMeta, Pool
 from trytond.model import ModelView, fields
 from trytond.pyson import Eval, Bool
+from trytond.transaction import Transaction
 
 
-__all__ = ['Agent', 'Commission']
-
-
-class Agent:
-    __metaclass__ = PoolMeta
+class Agent(metaclass=PoolMeta):
     __name__ = 'commission.agent'
     waiting_account = fields.Many2One('account.account', 'Waiting Account',
         domain=[
+            ('type', '!=', None),
+            ('closed', '!=', True),
             ('company', '=', Eval('company')),
-            ('kind', 'in', ['payable', 'other']),
             ],
-        depends=['company'])
+        depends=['company'],
+        help="The account the agent's waiting commission amounts are posted "
+        "to.")
 
 
-class Commission:
-    __metaclass__ = PoolMeta
+class Commission(metaclass=PoolMeta):
     __name__ = 'commission'
-    waiting_move = fields.Many2One('account.move', 'Move', readonly=True)
+    waiting_move = fields.Many2One(
+        'account.move', "Waiting Move", readonly=True)
 
     @classmethod
     def __setup__(cls):
@@ -36,6 +35,8 @@ class Commission:
     def copy(cls, commissions, default=None):
         if default is None:
             default = {}
+        else:
+            default = default.copy()
         default.setdefault('waiting_move', None)
         return super(Commission, cls).copy(commissions, default=default)
 
@@ -73,18 +74,19 @@ class Commission:
         period = Period.find(self.agent.company.id, date=date)
 
         move = Move(journal=self.get_journal(), origin=self,
-            date=date, period=period)
+            date=date, period=period, company=self.agent.company)
         amount = Currency.compute(self.currency, self.amount,
             self.agent.company.currency)
         line = Line()
-        if self.type_ == 'in':
-            line.credit = amount if amount > 0 else 0
-            line.debit = amount if amount < 0 else 0
-            line.account = self.product.account_revenue_used
-        else:
-            line.debit = amount if amount > 0 else 0
-            line.credit = amount if amount < 0 else 0
-            line.account = self.product.account_expense_used
+        with Transaction().set_context(date=date):
+            if self.type_ == 'in':
+                line.credit = amount if amount > 0 else 0
+                line.debit = amount if amount < 0 else 0
+                line.account = self.product.account_revenue_used
+            else:
+                line.debit = amount if amount > 0 else 0
+                line.credit = amount if amount < 0 else 0
+                line.account = self.product.account_expense_used
         if line.account.party_required:
             line.party = self.agent.party
         # XXX second currency?
